==> haskell-genvalidity-hspec-1.0.0.3-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.3
visibility:           public
id:                   genvalidity-hspec-1.0.0.3-BoL6oIUcEx47BshBO4K54X
key:                  genvalidity-hspec-1.0.0.3-BoL6oIUcEx47BshBO4K54X
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  368454969fa3bbf30c439e382933013d
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.3-BoL6oIUcEx47BshBO4K54X
depends:
    QuickCheck-2.14.3-JnDL91zTqvGA4sCcziUTy3 base-4.17.2.1
    genvalidity-1.1.1.0-62viiwzggkLGgDHBo7kNiU
    genvalidity-property-1.0.0.0-KdGCe0CQVHj8PLZYBWqLJR
    hspec-2.10.9-IlE8OnQguiJEoxUkXhWaKF
    hspec-core-2.10.9-Gm8mNnGPyaCJJfQaIQoyYm transformers-0.5.6.2
    validity-0.12.1.0-BT3scN1u48bJLw8PakTq5j

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-hspec-1.0.0.3-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.3
visibility:           public
id:                   genvalidity-hspec-1.0.0.3-6S5YKf734Q9H4SDxY0OFSP
key:                  genvalidity-hspec-1.0.0.3-6S5YKf734Q9H4SDxY0OFSP
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  568fc64392e879c0e6fa6dc1cc106594
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.3-6S5YKf734Q9H4SDxY0OFSP
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF base-4.17.2.1
    genvalidity-1.1.1.0-I7hsZbHO8bWGLcf58dOM84
    genvalidity-property-1.0.0.0-FqpYBaXVGaoLuAT0xU7j7C
    hspec-2.10.9-LrKv2WLw3ll63lZh5sx0BW
    hspec-core-2.10.9-GDNOEug74Za8kCbopvThyV transformers-0.5.6.2
    validity-0.12.1.0-1xHixWdzt8OH2pZuOzZ2rS

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
